package com.miaozhen.util;


import org.apache.ftpserver.ConnectionConfigFactory;
import org.apache.ftpserver.FtpServer;
import org.apache.ftpserver.FtpServerFactory;
import org.apache.ftpserver.ftplet.FtpException;
import org.apache.ftpserver.listener.ListenerFactory;
import org.apache.ftpserver.usermanager.impl.BaseUser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * The Class FTPServer.
 */
public class FTPServer {

    private static Logger log = LoggerFactory.getLogger(FTPServer.class);

    /** The port. */
    private int port;

    /** The user manager. */
    private InMemoryUserManager userManager;

    /** The server. */
    private FtpServer server;

    /**
     * Instantiates a new FTP server.
     */
    public FTPServer(){
        port = 21;
        userManager = new InMemoryUserManager();
    }

    /**
     * Sets the port.
     *
     * @param port the new port
     */
    public void setPort(int port){
        this.port = port;
    }

    /**
     * Sets the user.
     *
     * @param login the login
     * @param password the password
     * @param home the home
     */
    public void setUser(String login,char[] password,String home){
        BaseUser user = new BaseUser();
        user.setName(login);
        if(password !=null && password.length>0){
            user.setPassword(new String(password));
        }
        user.setHomeDirectory(home);
        user.setEnabled(true);
        userManager.setUser(user);
    }

    /**
     * Stop.
     */
    public void stop(){
        if (server!=null && !server.isStopped()){
            server.stop();
            server = null;
        }
    }

    /**
     * Start.
     */
    public boolean start(){

        ConnectionConfigFactory configFactory = new ConnectionConfigFactory();
        configFactory.setAnonymousLoginEnabled(false);
        configFactory.setMaxAnonymousLogins(0);

        configFactory.setMaxLoginFailures(5);
        configFactory.setLoginFailureDelay(30);

        configFactory.setMaxThreads(10);
        configFactory.setMaxLogins(10);

        ListenerFactory factory = new ListenerFactory();
        factory.setPort(port);

        FtpServerFactory serverFactory = new FtpServerFactory();
        serverFactory.addListener("default", factory.createListener());
        serverFactory.setUserManager(userManager);
        serverFactory.setConnectionConfig(configFactory.createConnectionConfig());

        server = serverFactory.createServer();

        try{
            server.start();
        } catch (FtpException ex){
            log.error("Start Ftp Server Error {}", ex);
            return false;
        }
        return true;

    }
}
